package com.onsiteservice.entity.order;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import javax.persistence.*;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

@Getter
@Setter
@ToString
@ApiModel("服务订单表")
@Table(name = "service_order")
public class ServiceOrder implements Serializable {
    /**
     * 主键
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @ApiModelProperty("主键")
    private Long id;

    /**
     * 订单号
     */
    @Column(name = "order_no")
    @ApiModelProperty("订单号")
    private String orderNo;

    /**
     * 服务名
     */
    @Column(name = "service_name")
    @ApiModelProperty("服务名")
    private String serviceName;

    /**
     * 账号
     */
    @Column(name = "account_no")
    @ApiModelProperty("账号")
    private Long accountNo;

    /**
     * 服务类型id
     */
    @Column(name = "subclass_id")
    @ApiModelProperty("服务类型id")
    private Integer subclassId;

    /**
     * 服务地址id
     */
    @Column(name = "address_id")
    @ApiModelProperty("服务地址id")
    private Long addressId;

    @Column(name = "name")
    @ApiModelProperty("客户名")
    private String name;

    @Column(name = "phone")
    @ApiModelProperty("客户服务手机号")
    private String phone;

    @Column(name = "address")
    @ApiModelProperty("客户服务地址")
    private String address;

    /**
     * 期望上门时间
     */
    @Column(name = "expect_arrival_time")
    @ApiModelProperty("期望上门时间")
    private Date expectArrivalTime;

    /**
     * 服务数量
     */
    @ApiModelProperty("服务数量")
    private Integer num;

    /**
     * 服务需求说明
     */
    @Column(name = "demand_desc")
    @ApiModelProperty("服务需求说明")
    private String demandDesc;

    /**
     * 是否阅读协议：1已阅读，0未阅读
     */
    @Column(name = "read_agreement")
    @ApiModelProperty("是否阅读协议：1已阅读，0未阅读")
    private Boolean readAgreement;

    /**
     * 订单状态：1用户下单，2派估价员或修改估价员，3发送订单，4支付，5派维修工或修改维修工，6完成订单，7取消订单
     */
    @Column(name = "order_status")
    @ApiModelProperty("订单状态：1用户下单，2派估价员或修改估价员，3发送订单，4支付，5派维修工或修改维修工，6完成订单，7取消订单")
    private Integer orderStatus;

    /**
     * 重新发送后的订单状态：3发送订单，4支付，5派维修工或修改维修工
     */
    @Column(name = "skip_work")
    @ApiModelProperty("跳过维修工，派过维修工后，该字段永久为为true")
    private Boolean skipWork;

    @Column(name = "total_price")
    @ApiModelProperty("订单总价格，以元为单位")
    private BigDecimal totalPrice;

    @Column(name = "price")
    @ApiModelProperty("当前发送订单操作的价格，以元为单位")
    private BigDecimal price;

    @Column(name = "pay_num")
    @ApiModelProperty("支付次数")
    private Integer payNum;

    /**
     * 服务订单备注字段
     */
    @Column(name = "remark")
    @ApiModelProperty("服务订单备注字段")
    private String remark;

    /**
     * 创建时间
     */
    @Column(name = "create_time")
    @ApiModelProperty("创建时间")
    private Date createTime;

    @Column(name = "create_by")
    @ApiModelProperty("创建人")
    private Long createBy;

    @Column(name = "modify_by")
    @ApiModelProperty("修改人")
    private Long modifyBy;

    @Column(name = "valuator_id")
    @ApiModelProperty("估价员id")
    private Long valuatorId;

    @Column(name = "cancel_time")
    @ApiModelProperty("订单自动取消时间")
    private Date cancelTime;


    private static final long serialVersionUID = 1L;
}